@@ -6,7 +6,7 @@
 
 /* $Header: /cvsroot/gnutelephony/testing/ccaudio2/gsm/debug.c,v 1.1.1.1 2005/04/23 22:09:16 dyfet Exp $ */
 
-#include "private.h"
+#include "gsm.h"
 
 #ifndef	NDEBUG
 
